@@ -2,3 +2,7 @@
 STATS_COORDINATOR_CUSTOMER_JOBS_STARTED_COUNT = "coordinator.customer.jobs.started"
 STATS_COORDINATOR_CUSTOMER_JOBS_WAITING_COUNT = "coordinator.customer.jobs.waiting"
 STATS_COORDINATOR_JOB_MISSING_WORKER_COUNT = "coordinator.job.worker.missing"
+STATS_COLLECTOR_JOB_LOGS_COUNT_MASK = "collector.job.logs.{}"
+
+
+STATS_USAGE_JOB_STATUS = "usage_job_status"
\ No newline at end of file
